##  Workspace Snapshot
To create a snapshot of your current workspace and clone all your data into a sandbox workspace, you must check the checkbox against Workspace Snapshots. Only when the checkbox is checked can Customer Support write data from another workspace into this workspace.
![Workspace Snapshot Import Confirmation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27569b4c7a4410148929d5447b277b5e_LowRes.png)
Workspace Snapshot Import Confirmation
**Remember**
  * To prevent unintentional writing of snapshot data into a workspace, the box is unchecked by default.
  * If you need sandbox workspaces as an add-on, please request them from your dedicated Customer Success Manager. For new contracts, sandbox workspaces are available as a paid feature.
